@@ -3,6 +3,7 @@ platform, focusing on the data and utility definition, avoiding any web
 communication issues."""
 
 import hashlib
+import logging
 from abc import ABC, abstractmethod
 from pathlib import Path
 from typing import Callable, Literal
@@ -10,6 +11,8 @@ from typing import Callable, Literal
 import anomed_utils as utils
 import numpy as np
 
+_logger = logging.getLogger(__name__)
+
 
 class NumpyDataset(ABC):
     """An abstract class defining a basic interface for handling datasets, based
@@ -47,6 +50,16 @@ class NumpyDataset(ABC):
         (X, y) = self.get()
         return f"NumpyDataset(X={str(X)}, y={str(y)})"
 
+    @property
+    def shapes(self) -> list[tuple[int, ...]]:
+        (X, y) = self.get()
+        return [X.shape, y.shape]
+
+    @property
+    def dtypes(self) -> list[np.dtype]:
+        (X, y) = self.get()
+        return [X.dtype, y.dtype]
+
 
 class NpzFromDisk(NumpyDataset):
     """An instance of a NumpyDataset, suitable for .npz files saved to disk."""
@@ -113,7 +126,7 @@ class SupervisedLearningMIAChallenge:
         validation_data: NumpyDataset,
         anonymizer_evaluator: Callable[[np.ndarray, np.ndarray], dict[str, float]],
         MIA_evaluator: Callable[[np.ndarray, np.ndarray], dict[str, float]],
-        MIA_evaluation_dataset_length: int = 100,
+        MIA_evaluation_dataset_length: int,
         seed: int | None = None,
     ):
         """
@@ -143,7 +156,8 @@ class SupervisedLearningMIAChallenge:
             The number of members and also the number of non-members to include
             in the return value of `MIA_evaluation_data`. That means in total,
             the length of that dataset will be
-            `2 * MIA_evaluation_dataset_length`. By default 100.
+            `2 * MIA_evaluation_dataset_length`. We suggest to set this to at
+            least 100.
         seed : int | None, optional
             If given, use this seed to create `members` and `non_members`. By
             default `None`, which means obtain randomness non-deterministically
@@ -178,6 +192,12 @@ class SupervisedLearningMIAChallenge:
         (members1, members2) = _random_partition(self.training_data, seed=self._seed)
         self._members_train = members1
         self._members_val = members2
+        _log_numpy_dataset_info(
+            headline="Initialized members:",
+            numpy_datasets=dict(
+                members_train=self._members_train, members_val=self._members_val
+            ),
+        )
 
     @property
     def non_members(self) -> NumpyDataset:
@@ -196,6 +216,13 @@ class SupervisedLearningMIAChallenge:
         )
         self._non_members_train = non_members1
         self._non_members_val = non_members2
+        _log_numpy_dataset_info(
+            headline="Initialized non-members:",
+            numpy_datasets=dict(
+                non_members_train=self._non_members_train,
+                non_members_val=self._non_members_val,
+            ),
+        )
 
     def MIA_evaluation_data(
         self,
@@ -295,6 +322,25 @@ class SupervisedLearningMIAChallenge:
         return self._MIA_evaluator(prediction, ground_truth)
 
 
+def _log_numpy_dataset_info(
+    headline: str | None,
+    numpy_datasets: dict[str, NumpyDataset],
+    level: int = logging.DEBUG,
+    logger: logging.Logger | None = None,
+):
+    if logger is None:
+        logger = _logger
+    indentation_spaces = 0
+    if headline is not None:
+        indentation_spaces = 4
+        logger.log(level=level, msg=headline)
+    for name, npds in numpy_datasets.items():
+        message = (
+            indentation_spaces * " "
+        ) + f"{name}: shapes={npds.shapes}, dtypes={npds.dtypes}"
+        logger.log(level=level, msg=message)
+
+
 def _create_membership_inference_evaluation_data(
     members: NumpyDataset,
     non_members: NumpyDataset,
@@ -304,6 +350,7 @@ def _create_membership_inference_evaluation_data(
     data_split: Literal["tuning", "validation"],
 ) -> tuple[NumpyDataset, np.ndarray]:
     hash_data = anonymizer + deanonymizer
+    _logger.debug(f"Using string `{hash_data}` to create seed deterministically.")
     seed = int(hashlib.sha256(hash_data.encode("utf-8")).hexdigest(), 16)
 
     # Split members and non-members into even parts (one for tuning, one for
@@ -314,6 +361,16 @@ def _create_membership_inference_evaluation_data(
     (non_members_subset_tuning, non_members_subset_validation) = _random_partition(
         non_members, seed=seed
     )
+    _log_numpy_dataset_info(
+        headline="Shapes and dtypes of the even parts:",
+        numpy_datasets=dict(
+            members_subset_tuning=members_subset_tuning,
+            members_subset_validation=members_subset_validation,
+            non_members_subset_tuning=non_members_subset_tuning,
+            non_members_subset_validation=non_members_subset_validation,
+        ),
+        level=logging.DEBUG,
+    )
 
     # Pick the relevant part
     if data_split == "tuning":
@@ -323,6 +380,7 @@ def _create_membership_inference_evaluation_data(
         # data_split == "validation"
         members_subset = members_subset_validation
         non_members_subset = non_members_subset_validation
+    _logger.debug(f"Selected datasets for {data_split}.")
 
     # Reduce the datasets to the desired size
     try:
@@ -338,6 +396,14 @@ def _create_membership_inference_evaluation_data(
             "elements to draw two disjoint MIA evaluation datasets (each of "
             f"length {2 * desired_length}) from them."
         )
+    _log_numpy_dataset_info(
+        headline="Shapes and dtypes of the reduced parts:",
+        numpy_datasets=dict(
+            members_subset=members_subset,
+            non_members_subset=non_members_subset,
+        ),
+        level=logging.DEBUG,
+    )
 
     # Go back to Numpy array representation for further processing
     (X_members, y_members) = members_subset.get()
@@ -350,8 +416,19 @@ def _create_membership_inference_evaluation_data(
     memberships = np.concatenate((members_mask, nonmembers_mask))
 
     [X, y, memberships] = utils.shuffles([X, y, memberships], seed=seed)
+    dataset = InMemoryNumpyArrays(X=X, y=y)
+    _log_numpy_dataset_info(
+        logger=_logger,
+        headline="Shapes and dtypes of the final evaluation parts:",
+        numpy_datasets=dict(dataset=dataset),
+        level=logging.DEBUG,
+    )
+    _logger.debug(
+        f"    For memberships, the shape is {memberships.shape} and the dtype is "
+        f"{memberships.dtype}."
+    )
 
-    return (InMemoryNumpyArrays(X=X, y=y), memberships)
+    return (dataset, memberships)
 
 
 def _random_partition(
