@@ -107,6 +107,18 @@ def test_NumpyDataset_repr(three_elem_ndarray):
     assert str(ds) == "NumpyDataset(X=[0 1 2], y=[0 1 2])"
 
 
+def test_NumpyDataset_shapes():
+    ds = InMemoryNumpyArrays(np.arange(10).reshape(2, 5), np.arange(9).reshape(3, 3))
+    assert ds.shapes == [(2, 5), (3, 3)]
+
+
+def test_NumpyDataset_dtypes(three_elem_ndarray):
+    ds = InMemoryNumpyArrays(
+        np.arange(10, dtype=np.int_), np.arange(5, dtype=np.float_)
+    )
+    assert ds.dtypes == [np.int_, np.float_]
+
+
 def test_discard_targets(example_dataset):
     discarded_dataset = challenge.discard_targets(example_dataset)
     (_, y) = discarded_dataset.get()
